You are viewing a plain text version of this content. The canonical link for it is here.
Posted to common-commits@hadoop.apache.org by xy...@apache.org on 2015/07/27 16:34:40 UTC

hadoop git commit: HDFS-8785. TestDistributedFileSystem is failing in trunk. Contributed by Xiaoyu Yao.

Repository: hadoop
Updated Branches:
  refs/heads/trunk 1df78688c -> 2196e39e1


HDFS-8785. TestDistributedFileSystem is failing in trunk. Contributed by Xiaoyu Yao.


Project: http://git-wip-us.apache.org/repos/asf/hadoop/repo
Commit: http://git-wip-us.apache.org/repos/asf/hadoop/commit/2196e39e
Tree: http://git-wip-us.apache.org/repos/asf/hadoop/tree/2196e39e
Diff: http://git-wip-us.apache.org/repos/asf/hadoop/diff/2196e39e

Branch: refs/heads/trunk
Commit: 2196e39e142b0f8d1944805db2bfacd4e3244625
Parents: 1df7868
Author: Xiaoyu Yao <xy...@apache.org>
Authored: Mon Jul 27 07:28:41 2015 -0700
Committer: Xiaoyu Yao <xy...@apache.org>
Committed: Mon Jul 27 07:28:41 2015 -0700

----------------------------------------------------------------------
 hadoop-hdfs-project/hadoop-hdfs/CHANGES.txt            |  2 ++
 .../apache/hadoop/hdfs/TestDistributedFileSystem.java  | 13 ++++++++-----
 2 files changed, 10 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/hadoop/blob/2196e39e/hadoop-hdfs-project/hadoop-hdfs/CHANGES.txt
----------------------------------------------------------------------
diff --git a/hadoop-hdfs-project/hadoop-hdfs/CHANGES.txt b/hadoop-hdfs-project/hadoop-hdfs/CHANGES.txt
index 1ddf7da..cc2a833 100644
--- a/hadoop-hdfs-project/hadoop-hdfs/CHANGES.txt
+++ b/hadoop-hdfs-project/hadoop-hdfs/CHANGES.txt
@@ -1084,6 +1084,8 @@ Release 2.8.0 - UNRELEASED
     HDFS-8810. Correct assertions in TestDFSInotifyEventInputStream class.
     (Surendra Singh Lilhore via aajisaka)
 
+    HDFS-8785. TestDistributedFileSystem is failing in trunk. (Xiaoyu Yao)
+
 Release 2.7.2 - UNRELEASED
 
   INCOMPATIBLE CHANGES

http://git-wip-us.apache.org/repos/asf/hadoop/blob/2196e39e/hadoop-hdfs-project/hadoop-hdfs/src/test/java/org/apache/hadoop/hdfs/TestDistributedFileSystem.java
----------------------------------------------------------------------
diff --git a/hadoop-hdfs-project/hadoop-hdfs/src/test/java/org/apache/hadoop/hdfs/TestDistributedFileSystem.java b/hadoop-hdfs-project/hadoop-hdfs/src/test/java/org/apache/hadoop/hdfs/TestDistributedFileSystem.java
index 0b77210..6012c5d 100644
--- a/hadoop-hdfs-project/hadoop-hdfs/src/test/java/org/apache/hadoop/hdfs/TestDistributedFileSystem.java
+++ b/hadoop-hdfs-project/hadoop-hdfs/src/test/java/org/apache/hadoop/hdfs/TestDistributedFileSystem.java
@@ -1189,19 +1189,22 @@ public class TestDistributedFileSystem {
     try {
       cluster.waitActive();
       DistributedFileSystem dfs = cluster.getFileSystem();
       // Write 1 MB to a dummy socket to ensure the write times out
       ServerSocket socket = new ServerSocket(0);
       Peer peer = dfs.getClient().newConnectedPeer(
         (InetSocketAddress) socket.getLocalSocketAddress(), null, null);
       long start = Time.now();
       try {
-        byte[] buf = new byte[1024 * 1024];
+        byte[] buf = new byte[10 * 1024 * 1024];
         peer.getOutputStream().write(buf);
-        Assert.fail("write should timeout");
+        long delta = Time.now() - start;
+        Assert.fail("write finish in " + delta + " ms" + "but should timedout");
       } catch (SocketTimeoutException ste) {
         long delta = Time.now() - start;
-        Assert.assertTrue("write timedout too soon", delta >= timeout * 0.9);
-        Assert.assertTrue("write timedout too late", delta <= timeout * 1.1);
+        Assert.assertTrue("write timedout too soon in " + delta + " ms",
+            delta >= timeout * 0.9);
+        Assert.assertTrue("write timedout too late in " + delta + " ms",
+            delta <= timeout * 1.2);
       } catch (Throwable t) {
         Assert.fail("wrong exception:" + t);
       }
@@ -1189,19 +1189,22 @@ public class TestDistributedFileSystem {
       cluster.waitActive();
       DistributedFileSystem dfs = cluster.getFileSystem();
-      // Write 1 MB to a dummy socket to ensure the write times out
+      // Write 10 MB to a dummy socket to ensure the write times out
       ServerSocket socket = new ServerSocket(0);
       Peer peer = dfs.getClient().newConnectedPeer(